summaryrefslogtreecommitdiff
path: root/sysdeps
diff options
context:
space:
mode:
authorRoland McGrath <roland@gnu.org>1996-03-02 21:37:50 +0000
committerRoland McGrath <roland@gnu.org>1996-03-02 21:37:50 +0000
commit36ff88f69e4c4016c4f3a88b888c1102329c6736 (patch)
tree30d74dce5e3623be27f6dc1510f6672792873774 /sysdeps
parent48a65a2993970a8f9f9011efb9d1355dd3cccb67 (diff)
Sat Mar 2 16:35:40 1996 Roland McGrath <roland@charlie-brown.gnu.ai.mit.edu>
* sysdeps/unix/sysv/linux/m68k/profil-counter.h: File removed. * sysdeps/unix/sysv/sysv4/solaris2/sparc/profil-counter.h: File removed. * sysdeps/generic/profil-counter.h: New file.
Diffstat (limited to 'sysdeps')
-rw-r--r--sysdeps/generic/profil-counter.h (renamed from sysdeps/unix/sysv/linux/m68k/profil-counter.h)7
-rw-r--r--sysdeps/unix/sysv/sysv4/solaris2/sparc/profil-counter.h24
2 files changed, 5 insertions, 26 deletions
diff --git a/sysdeps/unix/sysv/sysv4/solaris2/sparc/profil-counter.h b/sysdeps/unix/sysv/sysv4/solaris2/sparc/profil-counter.h
deleted file mode 100644
index be1a9328d1..0000000000
--- a/sysdeps/unix/sysv/sysv4/solaris2/sparc/profil-counter.h
+++ /dev/null
@@ -1,24 +0,0 @@
-/* Machine-dependent SIGPROF signal handler. Solaris2/sparc version.
-Copyright (C) 1996 Free Software Foundation, Inc.
-This file is part of the GNU C Library.
-
-The GNU C Library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Library General Public License as
-published by the Free Software Foundation; either version 2 of the
-License, or (at your option) any later version.
-
-The GNU C Library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-Library General Public License for more details.
-
-You should have received a copy of the GNU Library General Public
-License along with the GNU C Library; see the file COPYING.LIB. If
-not, write to the Free Software Foundation, Inc., 675 Mass Ave,
-Cambridge, MA 02139, USA. */
-
-static void
-profil_counter (int signr, int code, struct sigcontext *scp)
-{
- profil_count ((void *) scp->sc_pc);
-}
diff --git a/sysdeps/unix/sysv/linux/m68k/profil-counter.h b/sysdeps/generic/profil-counter.h
index 4e7b132dc9..6dc150febe 100644
--- a/sysdeps/unix/sysv/linux/m68k/profil-counter.h
+++ b/sysdeps/generic/profil-counter.h
@@ -1,4 +1,4 @@
/* Machine-dependent SIGPROF signal handler. Linux/m68k version.
Copyright (C) 1996 Free Software Foundation, Inc.
This file is part of the GNU C Library.
@@ -16,7 +16,10 @@ You should have received a copy of the GNU Library General Public
License along with the GNU C Library; see the file COPYING.LIB. If
not, write to the Free Software Foundation, Inc., 675 Mass Ave,
Cambridge, MA 02139, USA. */
-
+
+/* In many Unix systems signal handlers are called like this
+ and the interrupted PC is easily findable in the `struct sigcontext'. */
+
static void
profil_counter (int signr, int code, struct sigcontext *scp)
{
@@ -1,4 +1,4 @@
-/* Machine-dependent SIGPROF signal handler. Linux/m68k version.
+/* Machine-dependent SIGPROF signal handler. "Generic" version w/ sigcontext
Copyright (C) 1996 Free Software Foundation, Inc.
This file is part of the GNU C Library.